import { default as Action } from '../constants/ActionTypes';
import { default as Assets } from '../constants/AssetsTypes';
import { default as createReducer } from '../utils/createReducer';
const initialState = {
    columns: {
        [Assets.OVERVIEW]: [
            { binding: 'name', header: 'Name', width: 220, minWidth: 8, allowDragging: false, visible: true },
            { binding: 'open', header: 'Open', format: 'n2', width: 160, minWidth: 8, allowSorting: true, visible: true },
            {
                binding: 'close',
                header: 'Close',
                format: 'n2',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            { binding: 'high', header: 'High', format: 'n2', width: 160, minWidth: 8, allowSorting: true, visible: true },
            { binding: 'low', header: 'Low', format: 'n2', width: 160, minWidth: 8, allowSorting: true, visible: true },
            {
                binding: 'chg',
                header: 'Chg.',
                format: 'n2',
                align: 'center',
                width: 280,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'volume',
                header: 'Volume',
                format: 'n0',
                width: 160,
                minWidth: 8,
                align: 'center',
                allowSorting: true,
                visible: true
            },
            {
                binding: 'time',
                header: 'Time',
                width: 160,
                minWidth: 8,
                format: 'hh:mm:ss',
                align: 'center',
                allowSorting: true,
                visible: true
            },
            { width: '*', minWidth: 8 },
        ],
        [Assets.TECHNICAL]: [
            { binding: 'name', header: 'Name', width: 220, allowDragging: false, visible: true },
            {
                binding: 'technicalMinutes15',
                header: '15 Minutes',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowDragging: false,
                visible: true
            },
            {
                binding: 'technicalMinutes30',
                header: '30 Minutes',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'technicalHourly',
                header: 'Hourly',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'technicalWeekly',
                header: 'Weekly',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'technicalMonthly',
                header: 'Monthly',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            { width: '*', minWidth: 8 },
        ],
        [Assets.PERFORMANCE]: [
            { binding: 'name', header: 'Name', width: 220, allowDragging: false, visible: true },
            {
                binding: 'performanceDaily',
                header: 'Daily',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'performanceWeek',
                header: '1 Week',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'performanceMonth',
                header: '1 Month',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'performanceYtd',
                header: 'YTD',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'performanceYear',
                header: '1 Year',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            {
                binding: 'performanceYear3',
                header: '3 Years',
                format: 'n0',
                width: 160,
                minWidth: 8,
                allowSorting: true,
                visible: true
            },
            { width: '*', minWidth: 8 },
        ],
    },
    tickers: [],
    trading: [],
    filter: '',
};
/**
 * Data Reducers
 */
export default createReducer(initialState, {
    [Action.RECEIVE_TRADING_DATA]: (state, payload) => (Object.assign(Object.assign({}, state), { trading: payload })),
    [Action.RECEIVE_TICKERS_DATA]: (state, payload) => (Object.assign(Object.assign({}, state), { tickers: payload })),
    [Action.CHANGE_FILTER_TEXT]: (state, payload) => (Object.assign(Object.assign({}, state), { filter: payload })),
    [Action.CHANGE_COLUMN_VISIBILITY]: (state, payload) => {
        const { section, binding, visibility } = payload;
        const columns = Object.assign(Object.assign({}, state.columns), { [section]: state.columns[section].map(col => (col.binding === binding ? Object.assign(Object.assign({}, col), { visible: visibility }) : col)) });
        return Object.assign(Object.assign({}, state), { columns });
    },
});
